==> okindd-0.6.0-49-20110113.tar.bz2: okindd/src/picture.cpp <==
#include "picture.h"

pic::pic(QLabel * parent):QLabel(parent, Qt::X11BypassWindowManagerHint){
	picture_pic = new QPixmap();
	QDBusConnection dbusConnection = QDBusConnection (QDBusConnection::sessionBus());
	dbusConnection.connectToBus(QDBusConnection::SessionBus, "org.kochkin.okindd");
	if (!dbusConnection.registerService("org.kochkin.okindd")) {
		qDebug ("Service not registered. May be already running");
		}
	if (!dbusConnection.registerObject("/Picture", this, QDBusConnection::ExportAllSlots)) {
		qDebug ("Object /Picture not registered.");
		}
	time = new QTimer (this);
	connect (time, SIGNAL(timeout()), this, SLOT(hidePicture()));

	setPosition (workValue["PictureLeft"], workValue["PictureTop"]);
	picture_pic->load (workValue["PictureFile"]);
}

pic::~pic(){
}

void pic::hidePicture(){
	if (workValue["PictureTimer"].toInt() != 0) hide();
	time->stop();
}

void pic::mouseMoveEvent (QMouseEvent *e){
	move (e->globalPos()-clickPos);
	QDBusInterface mMoved ("org.kochkin.okindd-config", "/okindd");
	mMoved.call ("PicturePositionChanged", x(), y());
}

void pic::mousePressEvent (QMouseEvent *e){
	clickPos = e->pos();
	setCursor (Qt::SizeAllCursor);
}

void pic::mouseReleaseEvent (QMouseEvent *){
	setCursor (Qt::ArrowCursor);
}

void pic::setPosition(QString hPosition, QString vPosition){
	// Сделать поддержку профилей.
	//posHor=calcHPosition (hPosition, picture_pic->width(), workValue["PictureOffset"].toInt());
	//posVert=calcVPosition (vPosition, picture_pic->height(), workValue["PictureOffset"].toInt());
	posHor=calcHPosition (hPosition, picture_pic->width(), 0);
	posVert=calcVPosition (vPosition, picture_pic->height(), 0);
}

void pic::Picture (QString File, QString Left, QString Top, int Time){
	if (!File.isEmpty()) setPicture (File);
	setPosition (Left, Top);
	opacity=0.8;
	time->stop();
	if (time != 0) time->start (Time);
	hide();
	showPicture();
}

void pic::showCurrent(){
	setPosition (workValue["PictureLeft"], workValue["PictureTop"]);
	setOpacity (workValue["PictureOpacity"]);
	time->stop();
	if (time != 0) time->start (workValue["PictureTimer"].toInt());
	showPicture();
}

void pic::showPicture(){
	resize (picture_pic->width(), picture_pic->height());
	move (posHor,posVert);
	if (!QX11Info::isCompositingManagerRunning()) setAttribute (Qt::WA_PaintOnScreen);
	setAttribute (Qt::WA_TranslucentBackground);
	setWindowOpacity (opacity);
	show();
//	setUpdatesEnabled(true);
}

void pic::setOpacity (QString Opacity){
	if (Opacity.toFloat()<0) opacity=0;
		else if (Opacity.toFloat()>1) opacity=1;
			else opacity=Opacity.toFloat();
}

void pic::setPicture (QString pictureFile){
	picture_pic->load (pictureFile);
}

void pic::paintEvent (QPaintEvent *){
	QPainter p (this);
//	p.fillRect (0,0, picture_pic.width(), picture_pic.height(), Qt::transparent);
	p.drawPixmap (0,0,*picture_pic);

	QImage im = QImage (picture_pic->width(), picture_pic->height(), QImage::Format_ARGB32_Premultiplied);
	im.fill(0);
	QPainter mp;
	mp.begin (&im);
	mp.drawPixmap (0,0,*picture_pic);
	mp.end();
	if (!QX11Info::isCompositingManagerRunning()) setMask (QPixmap::fromImage(im).mask());
}

==> okindd-0.6.1-23-20120304.tar.bz2: okindd/src/picture.cpp <==
#include "picture.h"

pic::pic(QLabel * parent):QLabel(parent, Qt::X11BypassWindowManagerHint){
	dbusServiceRegister ("Picture", this);
	picture_pic = new QPixmap();
	time = new QTimer (this);
	connect (time, SIGNAL(timeout()), this, SLOT(hidePicture()));

	setPosition (workValue["PictureLeft"], workValue["PictureTop"]);
	picture_pic->load (workValue["PictureFile"]);
}

pic::~pic(){
}

void pic::hidePicture(){
	if (workValue["PictureTimer"].toInt() != 0) hide();
	time->stop();
}

void pic::mouseMoveEvent (QMouseEvent *e){
	move (e->globalPos()-clickPos);
	QDBusInterface mMoved ("org.kochkin.okindd-config", "/okindd");
	mMoved.call ("PicturePositionChanged", x(), y());
}

void pic::mousePressEvent (QMouseEvent *e){
	clickPos = e->pos();
	setCursor (Qt::SizeAllCursor);
}

void pic::mouseReleaseEvent (QMouseEvent *){
	setCursor (Qt::ArrowCursor);
}

void pic::setPosition(QString hPosition, QString vPosition){
	posHor=calcHPosition (hPosition, picture_pic->width(), 0);
	posVert=calcVPosition (vPosition, picture_pic->height(), 0);
}

void pic::Picture (QString File, QString Left, QString Top, int Time){
	if (!File.isEmpty()) setPicture (File);
	setPosition (Left, Top);
	opacity=0.8;
	time->stop();
	if (time != 0) time->start (Time);
	hide();
	showPicture();
}

void pic::showCurrent(){
	setPosition (workValue["PictureLeft"], workValue["PictureTop"]);
	setOpacity (workValue["PictureOpacity"]);
	time->stop();
	if (time != 0) time->start (workValue["PictureTimer"].toInt());
	showPicture();
}

void pic::showPicture(){
	resize (picture_pic->width(), picture_pic->height());
	move (posHor,posVert);
	if (!QX11Info::isCompositingManagerRunning()) setAttribute (Qt::WA_PaintOnScreen);
	setAttribute (Qt::WA_TranslucentBackground);
	setWindowOpacity (opacity);
	show();
}

void pic::setOpacity (QString Opacity){
	if (Opacity.toFloat()<0) opacity=0;
		else if (Opacity.toFloat()>1) opacity=1;
			else opacity=Opacity.toFloat();
}

void pic::setPicture (QString pictureFile){
	picture_pic->load (pictureFile);
}

void pic::paintEvent (QPaintEvent *){
	QPainter *p = new QPainter (this);
	p->drawPixmap (0,0,*picture_pic);
	QImage im = QImage (picture_pic->width(), picture_pic->height(), QImage::Format_ARGB32_Premultiplied);
	im.fill(0);
	QPainter mp;
	mp.begin (&im);
	mp.drawPixmap (0,0,*picture_pic);
	mp.end();
	if (!QX11Info::isCompositingManagerRunning()) setMask (QPixmap::fromImage(im).mask());
	p->end();
}
